nvector.objects.delta_E — nvector 0.7.5 documentation

# nvector.objects.delta_E

`delta_E`(point_a, point_b)

  > Returns cartesian delta vector from positions a to b decomposed in E.

  Parameters
    point_a, point_b: Nvector, GeoPoint or ECEFvector objects

      position a and b, decomposed in E.

  Returns
    p_ab_E: ECEFvector

      Cartesian position vector(s) from a to b, decomposed in E.

  Notes

  The calculation is exact, taking the ellipsity of the Earth into account. It is also non-singular as both n-vector and p-vector are non-singular (except for the center of the Earth).